@@ -84,10 +84,6 @@ class LibvirtInspector(virt_inspector.Inspector):
 
         return self._connection
 
-    def check_sanity(self):
-        if not self.connection:
-            raise virt_inspector.NoSanityException()
-
     @retry_on_disconnect
     def _lookup_by_uuid(self, instance):
         instance_name = util.instance_name(instance)
@@ -124,7 +120,10 @@ class LibvirtInspector(virt_inspector.Inspector):
             perf = stats[0][1]
             usage = perf["perf.cmt"]
             return virt_inspector.CPUL3CacheUsageStats(l3_cache_usage=usage)
-        except AttributeError as e:
+        except (KeyError, AttributeError) as e:
+            # NOTE(sileht): KeyError if for libvirt >=2.0.0,<2.3.0, the perf
+            # subsystem ws existing but not  these attributes
+            # https://github.com/libvirt/libvirt/commit/bae660869de0612bee2a740083fb494c27e3f80c
             msg = _('Perf is not supported by current version of libvirt, and '
                     'failed to inspect l3 cache usage of %(instance_uuid)s, '
                     'can not get info from libvirt: %(error)s') % {
@@ -264,7 +263,10 @@ class LibvirtInspector(virt_inspector.Inspector):
             perf = stats[0][1]
             return virt_inspector.MemoryBandwidthStats(total=perf["perf.mbmt"],
                                                        local=perf["perf.mbml"])
-        except AttributeError as e:
+        except (KeyError, AttributeError) as e:
+            # NOTE(sileht): KeyError if for libvirt >=2.0.0,<2.3.0, the perf
+            # subsystem ws existing but not  these attributes
+            # https://github.com/libvirt/libvirt/commit/bae660869de0612bee2a740083fb494c27e3f80c
             msg = _('Perf is not supported by current version of libvirt, and '
                     'failed to inspect memory bandwidth of %(instance_uuid)s, '
                     'can not get info from libvirt: %(error)s') % {
@@ -291,7 +293,10 @@ class LibvirtInspector(virt_inspector.Inspector):
                 instructions=perf["perf.instructions"],
                 cache_references=perf["perf.cache_references"],
                 cache_misses=perf["perf.cache_misses"])
-        except AttributeError as e:
+            # NOTE(sileht): KeyError if for libvirt >=2.0.0,<2.3.0, the perf
+            # subsystem ws existing but not  these attributes
+            # https://github.com/libvirt/libvirt/commit/bae660869de0612bee2a740083fb494c27e3f80c
+        except (AttributeError, KeyError) as e:
             msg = _LE('Perf is not supported by current version of libvirt, '
                       'and failed to inspect perf events of '
                       '%(instance_uuid)s, can not get info from libvirt: '
