@@ -18,7 +18,6 @@
 from keystoneauth1 import exceptions
 from oslo_config import cfg
 from oslo_log import log
-from oslo_utils import timeutils
 import six.moves.urllib.parse as urlparse
 
 from ceilometer.agent import plugin_base
@@ -117,7 +116,6 @@ class ContainersObjectsPollster(_Base):
                     user_id=None,
                     project_id=tenant,
                     resource_id=tenant + '/' + it.name,
-                    timestamp=timeutils.utcnow().isoformat(),
                     resource_metadata=None,
                 )
 
@@ -137,7 +135,6 @@ class ContainersSizePollster(_Base):
                         user_id=None,
                         project_id=tenant,
                         resource_id=tenant + '/' + it.name,
-                        timestamp=timeutils.utcnow().isoformat(),
                         resource_metadata=None,
                     )
 
@@ -156,7 +153,6 @@ class ObjectsSizePollster(_Base):
                 user_id=None,
                 project_id=tenant,
                 resource_id=tenant,
-                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=None,
                 )
 
@@ -175,7 +171,6 @@ class ObjectsPollster(_Base):
                 user_id=None,
                 project_id=tenant,
                 resource_id=tenant,
-                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=None,
                 )
 
@@ -192,7 +187,6 @@ class ObjectsContainersPollster(_Base):
                 user_id=None,
                 project_id=tenant,
                 resource_id=tenant,
-                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=None,
                 )
 
@@ -212,6 +206,5 @@ class UsagePollster(_Base):
                 user_id=None,
                 project_id=tenant,
                 resource_id=tenant,
-                timestamp=timeutils.utcnow().isoformat(),
                 resource_metadata=None,
                 )
