@@ -26,19 +26,17 @@ class TestPublisher(publisher.PublisherBase):
         self.events = []
         self.calls = 0
 
-    def publish_samples(self, context, samples):
+    def publish_samples(self, samples):
         """Send a metering message for publishing
 
-        :param context: Execution context from the service or RPC call
         :param samples: Samples from pipeline after transformation
         """
         self.samples.extend(samples)
         self.calls += 1
 
-    def publish_events(self, context, events):
+    def publish_events(self, events):
         """Send an event message for publishing
 
-        :param context: Execution context from the service or RPC call
         :param events: events from pipeline after transformation
         """
         self.events.extend(events)
