@@ -17,7 +17,6 @@ import copy
 import errno
 import os
 
-from oslo_log import log as logging
 from oslo_serialization import jsonutils as json
 import six
 from six.moves.urllib import parse as urllib
@@ -26,8 +25,6 @@ from tempest.lib import exceptions as lib_exc
 
 from ceilometer.tests.tempest.service.images import glance_http
 
-LOG = logging.getLogger(__name__)
-
 
 class ImagesClient(rest_client.RestClient):
 
