@@ -16,11 +16,10 @@
 
 import shutil
 
-from keystoneclient import exceptions as ks_exceptions
+from keystoneauth1 import exceptions as ka_exceptions
 import mock
 from novaclient import client as novaclient
 from oslo_config import fixture as fixture_config
-from oslo_service import service as os_service
 from oslo_utils import fileutils
 from oslotest import base
 from oslotest import mockpatch
@@ -36,6 +35,10 @@ from ceilometer import pipeline
 from ceilometer.tests.unit.agent import agentbase
 
 
+def fakedelayed(delay, target, *args, **kwargs):
+    return target(*args, **kwargs)
+
+
 class PollingException(Exception):
     pass
 
@@ -62,12 +65,27 @@ class TestManager(base.BaseTestCase):
         # currently we do have 26 disk-related pollsters
         self.assertEqual(26, len(list(mgr.extensions)))
 
+    def test_load_invalid_plugins_pollster_list(self):
+        # if no valid pollsters have been loaded, the ceilometer
+        # polling program should exit
+        self.assertRaisesRegexp(
+            manager.EmptyPollstersList,
+            'No valid pollsters can be loaded with the startup parameters'
+            ' polling-namespaces and pollster-list.',
+            manager.AgentManager,
+            pollster_list=['aaa'])
+
     def test_load_plugins_no_intersection(self):
         # Let's test nothing will be polled if namespace and pollsters
         # list have no intersection.
-        mgr = manager.AgentManager(namespaces=['compute'],
-                                   pollster_list=['storage.*'])
-        self.assertEqual(0, len(list(mgr.extensions)))
+        parameters = dict(namespaces=['compute'],
+                          pollster_list=['storage.*'])
+        self.assertRaisesRegexp(
+            manager.EmptyPollstersList,
+            'No valid pollsters can be loaded with the startup parameters'
+            ' polling-namespaces and pollster-list.',
+            manager.AgentManager,
+            parameters)
 
     # Test plugin load behavior based on Node Manager pollsters.
     # pollster_list is just a filter, so sensor pollsters under 'ipmi'
@@ -91,17 +109,17 @@ class TestManager(base.BaseTestCase):
     def test_load_failed_plugins(self, LOG):
         # Here we additionally check that namespaces will be converted to the
         # list if param was not set as a list.
-        mgr = manager.AgentManager(namespaces='ipmi',
-                                   pollster_list=['hardware.ipmi.node.*'])
-        # 0 pollsters
-        self.assertEqual(0, len(mgr.extensions))
-
-        err_msg = 'Skip loading extension for hardware.ipmi.node.%s'
-        pollster_names = [
-            'power', 'temperature', 'outlet_temperature',
-            'airflow', 'cups', 'cpu_util', 'mem_util', 'io_util']
-        calls = [mock.call(err_msg % n) for n in pollster_names]
-        LOG.exception.assert_has_calls(calls=calls, any_order=True)
+        try:
+            manager.AgentManager(namespaces='ipmi',
+                                 pollster_list=['hardware.ipmi.node.*'])
+        except manager.EmptyPollstersList:
+            err_msg = 'Skip loading extension for %s'
+            pollster_names = [
+                'power', 'temperature', 'outlet_temperature',
+                'airflow', 'cups', 'cpu_util', 'mem_util', 'io_util']
+            calls = [mock.call(err_msg, 'hardware.ipmi.node.%s' % n)
+                     for n in pollster_names]
+            LOG.exception.assert_has_calls(calls=calls, any_order=True)
 
     # Skip loading pollster upon ImportError
     @mock.patch('ceilometer.ipmi.pollsters.node._Base.__init__',
@@ -109,10 +127,14 @@ class TestManager(base.BaseTestCase):
     @mock.patch('ceilometer.ipmi.pollsters.sensor.SensorPollster.__init__',
                 mock.Mock(return_value=None))
     def test_import_error_in_plugin(self):
-        mgr = manager.AgentManager(namespaces=['ipmi'],
-                                   pollster_list=['hardware.ipmi.node.*'])
-        # 0 pollsters
-        self.assertEqual(0, len(mgr.extensions))
+        parameters = dict(namespaces=['ipmi'],
+                          pollster_list=['hardware.ipmi.node.*'])
+        self.assertRaisesRegexp(
+            manager.EmptyPollstersList,
+            'No valid pollsters can be loaded with the startup parameters'
+            ' polling-namespaces and pollster-list.',
+            manager.AgentManager,
+            parameters)
 
     # Exceptions other than ExtensionLoadError are propagated
     @mock.patch('ceilometer.ipmi.pollsters.node._Base.__init__',
@@ -242,7 +264,6 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
         self.notifier.sample.side_effect = self.fake_notifier_sample
         self.useFixture(mockpatch.Patch('oslo_messaging.Notifier',
                                         return_value=self.notifier))
-        self.source_resources = True
         super(TestRunTasks, self).setUp()
         self.useFixture(mockpatch.Patch(
             'keystoneclient.v2_0.client.Client',
@@ -276,13 +297,13 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
         """Test for bug 1316532."""
         self.useFixture(mockpatch.Patch(
             'keystoneclient.v2_0.client.Client',
-            side_effect=ks_exceptions.ClientException))
+            side_effect=ka_exceptions.ClientException))
         self.pipeline_cfg = {
             'sources': [{
                 'name': "test_keystone",
                 'interval': 10,
                 'meters': ['testkeystone'],
-                'resources': ['test://'] if self.source_resources else [],
+                'resources': ['test://'],
                 'sinks': ['test_sink']}],
             'sinks': [{
                 'name': 'test_sink',
@@ -323,8 +344,8 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
                                   None,
                                   None,
                                   discovery.NodesDiscoveryTripleO())
-        self.mgr.discovery_manager = (extension.ExtensionManager
-                                      .make_test_instance([ext]))
+        self.mgr.discoveries = (extension.ExtensionManager
+                                .make_test_instance([ext]))
 
         self.pipeline_cfg = {
             'sources': [{
@@ -351,7 +372,7 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
                 'name': source_name,
                 'interval': 10,
                 'meters': ['testpollingexception'],
-                'resources': ['test://'] if self.source_resources else [],
+                'resources': ['test://'],
                 'sinks': ['test_sink']}],
             'sinks': [{
                 'name': 'test_sink',
@@ -384,7 +405,9 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
         self._batching_samples(4, 1)
 
     def _batching_samples(self, expected_samples, call_count):
-        pipeline = yaml.dump({
+        self.useFixture(mockpatch.PatchObject(manager.utils, 'delayed',
+                                              side_effect=fakedelayed))
+        pipeline_cfg = {
             'sources': [{
                 'name': 'test_pipeline',
                 'interval': 1,
@@ -395,18 +418,12 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
                 'name': 'test_sink',
                 'transformers': [],
                 'publishers': ["test"]}]
-        })
+        }
 
-        pipeline_cfg_file = self.setup_pipeline_file(pipeline)
-
-        self.CONF.set_override("pipeline_cfg_file", pipeline_cfg_file)
-
-        self.mgr.tg = os_service.threadgroup.ThreadGroup(1000)
-        self.mgr.start()
-        # Manually executes callbacks
-        for timer in self.mgr.pollster_timers:
-            timer.f(*timer.args, **timer.kw)
+        self.mgr.polling_manager = pipeline.PollingManager(pipeline_cfg)
+        polling_task = list(self.mgr.setup_polling_tasks().values())[0]
 
+        self.mgr.interval_task(polling_task)
         samples = self.notified_samples
         self.assertEqual(expected_samples, len(samples))
         self.assertEqual(call_count, self.notifier.sample.call_count)
@@ -422,7 +439,7 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
                 'name': 'test_pipeline',
                 'interval': 1,
                 'meters': ['test'],
-                'resources': ['test://'] if self.source_resources else [],
+                'resources': ['test://'],
                 'sinks': ['test_sink']}],
             'sinks': [{
                 'name': 'test_sink',
@@ -433,8 +450,8 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
         pipeline_cfg_file = self.setup_pipeline_file(pipeline)
 
         self.CONF.set_override("pipeline_cfg_file", pipeline_cfg_file)
-        self.mgr.tg = os_service.threadgroup.ThreadGroup(1000)
-        self.mgr.start()
+        self.mgr.run()
+        self.addCleanup(self.mgr.terminate)
 
         # we only got the old name of meters
         for sample in self.notified_samples:
@@ -448,7 +465,7 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
                 'name': 'test_pipeline',
                 'interval': 1,
                 'meters': ['testanother'],
-                'resources': ['test://'] if self.source_resources else [],
+                'resources': ['test://'],
                 'sinks': ['test_sink']}],
             'sinks': [{
                 'name': 'test_sink',
@@ -458,7 +475,7 @@ class TestRunTasks(agentbase.BaseAgentManagerTestCase):
 
         updated_pipeline_cfg_file = self.setup_pipeline_file(pipeline)
 
-        # Move/re-name the updated pipeline file to the original pipeline
+        # Move/rename the updated pipeline file to the original pipeline
         # file path as recorded in oslo config
         shutil.move(updated_pipeline_cfg_file, pipeline_cfg_file)
 
